.. _swh-fuse:

.. include:: README.rst


.. toctree::
   :maxdepth: 1
   :caption: Overview

   cli
   configuration
   Design notes <design>
   Tutorial <tutorial>
   API reference </apidoc/swh.fuse>
